package sk.kasv.guiworld;

import javafx.fxml.FXML;
import javafx.scene.control.*;
import javafx.scene.text.Text;
import sk.kasv.guiworld.database.MySQLDatabase;

import java.sql.SQLException;

public class FormController {
    public CheckBox language;

    @FXML
    private Label infoLabel;

    @FXML
    private RadioButton celsius;

    @FXML
    private RadioButton fahrenheit;

    @FXML
    private RadioButton kelvin;

    @FXML
    private Text tempText;

    @FXML
    private Label resultLabel;
    @FXML
    private ChoiceBox<String> countriesBox;
    @FXML
    private ChoiceBox<String> citiesBox;


    private final API api = new API();

    @FXML
    private void initialize() throws SQLException {
        countriesBox.setItems(MySQLDatabase.getInstance().getAllCountries());
        countriesBox.setValue("Select country");

        countriesBox.getSelectionModel().selectedItemProperty().addListener((observable, oldValue, countryName) -> {
            if (countryName != null && !countryName.equals("Select country")) {
                try {
                    citiesBox.setItems(MySQLDatabase.getInstance().getAllCities(countryName));
                    citiesBox.setValue("Select city");
                } catch (SQLException e) {
                    e.printStackTrace();
                }
            }
        });


        citiesBox.setOnAction(event -> {
            String selectedCity = citiesBox.getValue();
            if (!"Select city".equals(selectedCity)) {
                try {
                    boolean includeLanguage = handleOfficialLanguageCheckbox();
                    String info;
                    if (includeLanguage) {
                        info = String.valueOf(MySQLDatabase.getInfoByCity(selectedCity));
                    } else {
                        info = String.valueOf(MySQLDatabase.getInfoByCityNoLanguage(selectedCity));
                    }
                    infoLabel.setText(info);
                } catch (SQLException e) {
                    e.printStackTrace();
                }
            } else {
                infoLabel.setText("");
            }
        });
        fahrenheit.setOnAction(event -> TemperatureSelect(fahrenheit, "Fahrenheit"));
        celsius.setOnAction(event -> TemperatureSelect(celsius, "Celsius"));
        kelvin.setOnAction(event -> TemperatureSelect(kelvin, "Kelvin"));
    }

    private void TemperatureSelect(RadioButton selectedButton, String scale) {
        if (selectedButton.isSelected()) {
            fahrenheit.setSelected(selectedButton == fahrenheit);
            celsius.setSelected(selectedButton == celsius);
            kelvin.setSelected(selectedButton == kelvin);

            double temp = api.getTemperature(citiesBox.getValue());

            if (scale.equals("Celsius")) {
                double temperatureCelsius = temp - 273.15;
                System.out.println(temperatureCelsius);
                tempText.setText(String.format("%.2f", temperatureCelsius) + " °C");
            } else if (scale.equals("Fahrenheit")) {
                double temperatureFahrenheit = (temp - 273.15) * 9 / 5 + 32;
                System.out.println(temperatureFahrenheit);
                tempText.setText(String.format("%.2f", temperatureFahrenheit) + " °F");
            } else if (scale.equals("Kelvin")) {
                System.out.println(temp);
                tempText.setText(String.format("%.2f", temp) + " K");
            } else {
                tempText.setText("");
            }
        }
    }

    @FXML
    private boolean handleOfficialLanguageCheckbox() {
        if (language.isSelected()) {
            System.out.println("Official language is selected");
            return true;
        } else {
            System.out.println("Official language is not selected");
            return false;
        }
    }
}