package sk.kasv.guiworld.database;

import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import sk.kasv.guiworld.model.City;
import sk.kasv.guiworld.model.Country;

import java.sql.*;
import java.util.ArrayList;
import java.util.List;

public class MySQLDatabase {
    // SINGLETON
    private static MySQLDatabase mySQLDatabase;
    private static final String URL = "jdbc:mysql://localhost:3306/world_x";
    private static final String USER = "root";
    private static final String PASS = "";
    private static final String SELECT_ALL_COUNTRIES = "SELECT name FROM country";
    private static final String SELECT_INFO_BY_COUNTRY = "SELECT countrylanguage.Language, country.Code2, city.CountryCode FROM city JOIN country ON " +
            "city.CountryCode = country.code JOIN countrylanguage ON country.code = countrylanguage.CountryCode WHERE city.name = ? AND " +
            "countrylanguage.IsOfficial = 'T';";
    private static final String SELECT_ALL_CITIES = "SELECT city.name FROM city JOIN country ON city.CountryCode = country.code WHERE country.name = ?;";
    private static final String SELECT_INFO_BY_COUNTRY_NO_LANGUAGE = "SELECT city.CountryCode, country.Code2 FROM city JOIN country ON " +
            "city.CountryCode = country.code WHERE city.name = ?;";

    private MySQLDatabase() {
    }

    public static MySQLDatabase getInstance() {
        if (mySQLDatabase == null) {
            mySQLDatabase = new MySQLDatabase();
        }
        return mySQLDatabase;
    }

    public static void main(String[] args) throws SQLException {
        System.out.println(getInfoByCity("Bratislava"));
    }

    public ObservableList<String> getAllCountries() throws SQLException {
        Connection conn = DriverManager.getConnection(URL,USER,PASS);
        Statement statement = conn.createStatement();
        ResultSet rs = statement.executeQuery(SELECT_ALL_COUNTRIES);
        List<String> countries = new ArrayList<>();

        while (rs.next()) {
            String countryName = rs.getString("name");
            countries.add(countryName);
        }
        return FXCollections.observableList(countries);
    }

    public static ObservableList<String> getAllCities(String country) throws SQLException {
        List<String> cities = new ArrayList<>();
        Connection conn = DriverManager.getConnection(URL,USER,PASS);
        PreparedStatement statement = conn.prepareStatement(SELECT_ALL_CITIES);
        statement.setString(1, country);

        ResultSet rs = statement.executeQuery();
        while (rs.next()) {
            String cityName = rs.getString("name");
            cities.add(cityName);
        }
        return FXCollections.observableList(cities);
    }

    public static Country getInfoByCity(String city) throws SQLException {
        Connection conn = DriverManager.getConnection(URL, USER, PASS);
        PreparedStatement preparedStatement = conn.prepareStatement(SELECT_INFO_BY_COUNTRY);
        preparedStatement.setString(1, city);
        ResultSet resultSet = preparedStatement.executeQuery();
        Country country = null;
        if (resultSet.next()) {
            String language = resultSet.getString("Language");
            String code = resultSet.getString("Code2");
            String countryCode = resultSet.getString("CountryCode");
            country = new Country(language, code, countryCode);
        }
        conn.close();
        return country;
    }

    public static Country getInfoByCityNoLanguage(String city) throws SQLException {
        Connection conn = DriverManager.getConnection(URL, USER, PASS);
        PreparedStatement preparedStatement = conn.prepareStatement(SELECT_INFO_BY_COUNTRY_NO_LANGUAGE);
        preparedStatement.setString(1, city);
        ResultSet resultSet = preparedStatement.executeQuery();
        Country country = null;
        if (resultSet.next()) {
            String code = resultSet.getString("Code2");
            String countryCode = resultSet.getString("CountryCode");
            country = new Country(code, countryCode);
        }
        conn.close();
        return country;
    }
}